@@ -16,7 +16,6 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: reflect.c,v 1.11 2003/04/15 15:43:52 nalin Exp $"
 #include "../config.h"
 #include <sys/types.h>
 #include <stdio.h>
@@ -28,11 +27,6 @@
 #ifdef USE_VTE
 #include "vte.h"
 #endif
-#ifdef USE_ZVT
-#ifdef HAVE_ZVT
-#include <libzvt/libzvt.h>
-#endif
-#endif
 
 static GArray *contents = NULL;
 
@@ -88,90 +82,6 @@ terminal_adjustment_vte(GtkWidget *terminal)
 	return (VTE_TERMINAL(terminal))->adjustment;
 }
 #endif
-#ifdef USE_ZVT
-#ifdef HAVE_ZVT
-/*
- * Implementation for a ZvtTerm widget.
- */
-static void
-terminal_hint_zvt(GtkWidget *widget, gpointer data)
-{
-	ZvtTerm *terminal;
-	GtkStyle *style;
-	GdkGeometry hints;
-	GtkWidget *toplevel;
-
-	terminal = ZVT_TERM(widget);
-
-	toplevel = gtk_widget_get_toplevel(widget);
-	g_assert(toplevel != NULL);
-
-	gtk_widget_ensure_style(widget);
-	style = widget->style;
-	hints.base_width = style->xthickness * 2 + 2;
-	hints.base_height = style->ythickness * 2;
-
-	hints.width_inc = terminal->charwidth;
-	hints.height_inc = terminal->charheight;
-	hints.min_width = hints.base_width + hints.width_inc;
-	hints.min_height = hints.base_height + hints.height_inc;
-
-	gtk_window_set_geometry_hints(GTK_WINDOW(toplevel),
-				      widget,
-				      &hints,
-				      GDK_HINT_RESIZE_INC |
-				      GDK_HINT_MIN_SIZE |
-				      GDK_HINT_BASE_SIZE);
-	gtk_widget_queue_resize(widget);
-}
-static void
-terminal_init_zvt(GtkWidget **terminal)
-{
-	*terminal = zvt_term_new();
-	g_signal_connect_after(G_OBJECT(*terminal), "realize",
-			       G_CALLBACK(terminal_hint_zvt), NULL);
-}
-static void
-terminal_shell_zvt(GtkWidget *terminal)
-{
-	const char *shell;
-	shell = getenv("SHELL") ? getenv("SHELL") : "/bin/sh";
-	g_signal_connect(G_OBJECT(terminal), "child-died",
-			 G_CALLBACK(gtk_main_quit), NULL);
-	if (zvt_term_forkpty(ZVT_TERM(terminal), 0) == 0) {
-		execlp(shell, shell, NULL);
-		g_assert_not_reached();
-	}
-}
-static GtkAdjustment *
-terminal_adjustment_zvt(GtkWidget *terminal)
-{
-	return (ZVT_TERM(terminal))->adjustment;
-}
-#else
-/*
- * Implementation for broken setups.
- */
-static void
-terminal_init_broken(GtkWidget **terminal)
-{
-	g_error("libzvt not found at compile-time");
-	_exit(1);
-}
-static void
-terminal_shell_broken(GtkWidget *terminal)
-{
-	g_error("libzvt not found at compile-time");
-	_exit(1);
-}
-static GtkAdjustment *
-terminal_adjustment_broken(GtkWidget *terminal)
-{
-	g_error("libzvt not found at compile-time");
-	_exit(1);
-}
-#endif
-#endif
 
 /*
  * Update the contents of the widget with the data from our contents array.
@@ -183,14 +93,14 @@ update_contents(AtkObject *obj, GtkWidget *widget)
 	GString *s;
 
 	caret = atk_text_get_caret_offset(ATK_TEXT(obj));
-	s = g_string_new("");
+	s = g_string_new(NULL);
 	for (i = 0; i < contents->len; i++) {
 		if (i == caret) {
 			s = g_string_append(s, "[CARET]");
 		}
 		s = g_string_append_unichar(s,
 					    g_array_index(contents,
-						   	  gunichar,
+							  gunichar,
 							  i));
 	}
 	if (i == caret) {
@@ -198,6 +108,16 @@ update_contents(AtkObject *obj, GtkWidget *widget)
 	}
 	if (GTK_IS_LABEL(widget)) {
 		gtk_label_set_text(GTK_LABEL(widget), s->str);
+		gtk_label_set_selectable(GTK_LABEL(widget),
+					 atk_text_get_n_selections(ATK_TEXT(obj)) > 0);
+		if (gtk_label_get_selectable(GTK_LABEL(widget))) {
+			int selection_start, selection_end;
+			atk_text_get_selection(ATK_TEXT(obj), 0,
+					       &selection_start,
+					       &selection_end);
+			gtk_label_select_region(GTK_LABEL(widget),
+						selection_start, selection_end);
+		}
 	}
 	g_string_free(s, TRUE);
 }
@@ -272,20 +192,17 @@ text_caret_moved(AtkObject *obj, gint offset, gpointer data)
 	update_contents(obj, GTK_WIDGET(data));
 }
 
+static void
+text_selection_changed(AtkObject *obj, gpointer data)
+{
+	update_contents(obj, GTK_WIDGET(data));
+}
+
 /* Wrapper versions. */
 static void
 terminal_init(GtkWidget **terminal)
 {
 	*terminal = NULL;
-#ifdef USE_ZVT
-#ifdef HAVE_ZVT
-	terminal_init_zvt(terminal);
-	return;
-#else
-	terminal_init_broken(terminal);
-	return;
-#endif
-#endif
 #ifdef USE_TEXT_VIEW
 	terminal_init_text_view(terminal);
 	return;
@@ -299,15 +216,6 @@ terminal_init(GtkWidget **terminal)
 static void
 terminal_shell(GtkWidget *terminal)
 {
-#ifdef USE_ZVT
-#ifdef HAVE_ZVT
-	terminal_shell_zvt(terminal);
-	return;
-#else
-	terminal_shell_broken(terminal);
-	return;
-#endif
-#endif
 #ifdef USE_TEXT_VIEW
 	terminal_shell_text_view(terminal);
 	return;
@@ -321,13 +229,6 @@ terminal_shell(GtkWidget *terminal)
 static GtkAdjustment *
 terminal_adjustment(GtkWidget *terminal)
 {
-#ifdef USE_ZVT
-#ifdef HAVE_ZVT
-	return terminal_adjustment_zvt(terminal);
-#else
-	return terminal_adjustment_broken(terminal);
-#endif
-#endif
 #ifdef USE_TEXT_VIEW
 	return terminal_adjustment_text_view(terminal);
 #endif
@@ -399,6 +300,8 @@ main(int argc, char **argv)
 			 G_CALLBACK(text_changed_delete), label);
 	g_signal_connect(G_OBJECT(obj), "text-caret-moved",
 			 G_CALLBACK(text_caret_moved), label);
+	g_signal_connect(G_OBJECT(obj), "text-selection-changed",
+			 G_CALLBACK(text_selection_changed), label);
 
 	count = atk_text_get_character_count(ATK_TEXT(obj));
 	if (count > 0) {
