@@ -16,7 +16,6 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: ring.c,v 1.20 2006/01/15 21:09:40 gpastore Exp $"
 #include "../config.h"
 #include <stdio.h>
 #include <string.h>
@@ -54,7 +53,7 @@ _vte_ring_validate(VteRing * ring)
 VteRing *
 _vte_ring_new(glong max_elements, VteRingFreeFunc free, gpointer data)
 {
-	VteRing *ret = g_malloc0(sizeof(VteRing));
+	VteRing *ret = g_slice_new0(VteRing);
 	ret->user_data = data;
 	ret->delta = ret->length = 0;
 	ret->max = MAX(max_elements, 2);
@@ -241,10 +240,10 @@ _vte_ring_insert_preserve(VteRing * ring, long position, gpointer data)
  * _vte_ring_remove:
  * @ring: a #VteRing
  * @position: an index
- * @free_element: TRUE if the item should be freed
+ * @free_element: %TRUE if the item should be freed
  *
  * Removes the @position'th item from @ring, freeing it only if @free_element is
- * TRUE.
+ * %TRUE.
  *
  */
 void
@@ -311,7 +310,7 @@ _vte_ring_append(VteRing * ring, gpointer data)
 /**
  * _vte_ring_free:
  * @ring: a #VteRing
- * @free_elements: TRUE if items in the ring should be freed
+ * @free_elements: %TRUE if items in the ring should be freed
  *
  * Frees the ring and, optionally, each of the items it contains.
  *
@@ -334,7 +333,7 @@ _vte_ring_free(VteRing * ring, gboolean free_elements)
 	ring->user_data = NULL;
 	ring->array = NULL;
 	ring->delta = ring->length = ring->max = 0;
-	g_free(ring);
+	g_slice_free(VteRing, ring);
 }
 
 #ifdef RING_MAIN
