@@ -679,11 +679,10 @@ main(int argc, char **argv)
 	}
 
 	/* Set the default font. */
-	if (font == NULL) {
-		font = "Monospace 12";
+	if (font) {
+		vte_terminal_set_font_from_string_full(VTE_TERMINAL(widget),
+						       font, antialias);
 	}
-	vte_terminal_set_font_from_string_full(VTE_TERMINAL(widget),
-					       font, antialias);
 
 	/* Match "abcdefg". */
 	vte_terminal_match_add(VTE_TERMINAL(widget), "abcdefg");
