@@ -21,11 +21,11 @@
 #ifndef vte_vtedraw_h_included
 #define vte_vtedraw_h_included
 
-#ident "$Id: vtedraw.h,v 1.8 2003/06/16 21:15:10 nalin Exp $"
 
 #include <glib.h>
 #include <gtk/gtk.h>
 #include "vtebg.h"
+#include "vte.h"
 
 G_BEGIN_DECLS
 
@@ -57,7 +57,7 @@ struct _vte_draw_impl {
 	GdkColormap* (*get_colormap)(struct _vte_draw *draw);
 	void (*start)(struct _vte_draw *draw);
 	void (*end)(struct _vte_draw *draw);
-	void (*set_background_color)(struct _vte_draw *, GdkColor *);
+	void (*set_background_color)(struct _vte_draw *, GdkColor *, guint16);
 	void (*set_background_image)(struct _vte_draw *,
 				     enum VteBgSourceType type,
 				     GdkPixbuf *pixbuf,
@@ -66,7 +66,9 @@ struct _vte_draw_impl {
 				     double saturation);
 	gboolean requires_repaint;
 	void (*clear)(struct _vte_draw *, gint, gint, gint, gint);
-	void (*set_text_font)(struct _vte_draw *, const PangoFontDescription *);
+	void (*set_text_font)(struct _vte_draw *,
+			      const PangoFontDescription *,
+			      VteTerminalAntiAlias);
 	int (*get_text_width)(struct _vte_draw *);
 	int (*get_text_height)(struct _vte_draw *);
 	int (*get_text_ascent)(struct _vte_draw *);
@@ -113,7 +115,9 @@ void _vte_draw_end(struct _vte_draw *draw);
 
 /* Set the background color, a background pixbuf (if you want transparency,
    you'll have to do that yourself), and clear an area to the default. */
-void _vte_draw_set_background_color(struct _vte_draw *draw, GdkColor *color);
+void _vte_draw_set_background_color(struct _vte_draw *draw,
+				    GdkColor *color,
+				    guint16 opacity);
 void _vte_draw_set_background_image(struct _vte_draw *draw,
 				    enum VteBgSourceType type,
 				    GdkPixbuf *pixbuf,
@@ -126,7 +130,8 @@ void _vte_draw_clear(struct _vte_draw *draw,
 
 /* Set the font which will be used to draw text. */
 void _vte_draw_set_text_font(struct _vte_draw *draw,
-			     const PangoFontDescription *fontdesc);
+			     const PangoFontDescription *fontdesc,
+			     VteTerminalAntiAlias anti_alias);
 /* Read font metrics. */
 int _vte_draw_get_text_width(struct _vte_draw *draw);
 int _vte_draw_get_text_height(struct _vte_draw *draw);
