@@ -171,7 +171,7 @@ _vte_pango_end(struct _vte_draw *draw)
 }
 
 static void
-_vte_pango_set_background_color(struct _vte_draw *draw, GdkColor *color)
+_vte_pango_set_background_color(struct _vte_draw *draw, GdkColor *color, guint16 opacity)
 {
 	struct _vte_pango_data *data;
 	data = (struct _vte_pango_data*) draw->impl_data;
