@@ -16,7 +16,6 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: vteskel.c,v 1.8 2003/05/28 21:53:59 nalin Exp $"
 
 #include "../config.h"
 
@@ -34,6 +33,7 @@ struct _vte_skel_data
 	GdkPixmap *pixmap;
 	gint pixmapw, pixmaph;
 	gint scrollx, scrolly;
+	guint16 opacity;
 };
 
 static gboolean
@@ -48,7 +48,7 @@ _vte_skel_create(struct _vte_draw *draw, GtkWidget *widget)
 {
 	struct _vte_skel_data *data;
 
-	draw->impl_data = g_malloc(sizeof(struct _vte_skel_data));
+	draw->impl_data = g_slice_new(struct _vte_skel_data);
 	data = (struct _vte_skel_data*) draw->impl_data;
 
 	data->color.red = 0;
@@ -75,7 +75,7 @@ _vte_skel_destroy(struct _vte_draw *draw)
 
 	memset(&data->color, 0, sizeof(data->color));
 
-	g_free(draw->impl_data);
+	g_slice_free(struct _vte_skel_data, draw->impl_data);
 }
 
 static GdkVisual *
@@ -107,11 +107,12 @@ _vte_skel_end(struct _vte_draw *draw)
 }
 
 static void
-_vte_skel_set_background_color(struct _vte_draw *draw, GdkColor *color)
+_vte_skel_set_background_color(struct _vte_draw *draw, GdkColor *color, guint16 opacity)
 {
 	struct _vte_skel_data *data;
 	data = (struct _vte_skel_data*) draw->impl_data;
 	data->color = *color;
+	data->opacity = opacity;
 }
 
 static void
@@ -137,7 +138,8 @@ _vte_skel_clear(struct _vte_draw *draw,
 
 static void
 _vte_skel_set_text_font(struct _vte_draw *draw,
-			const PangoFontDescription *fontdesc)
+			const PangoFontDescription *fontdesc,
+			VteTerminalAntiAlias antialias)
 {
 	struct _vte_skel_data *data;
 	data = (struct _vte_skel_data*) draw->impl_data;
@@ -161,6 +163,12 @@ _vte_skel_get_text_ascent(struct _vte_draw *draw)
 	return draw->ascent;
 }
 
+static int
+_vte_skel_get_char_width(struct _vte_draw *draw, gunichar c, int columns)
+{
+	return _vte_skel_get_text_width(draw) * columns;
+}
+
 static gboolean
 _vte_skel_get_using_fontconfig(struct _vte_draw *draw)
 {
@@ -230,6 +238,7 @@ struct _vte_draw_impl _vte_draw_skel = {
 	_vte_skel_get_text_width,
 	_vte_skel_get_text_height,
 	_vte_skel_get_text_ascent,
+	_vte_skel_get_char_width,
 	_vte_skel_get_using_fontconfig,
 	_vte_skel_draw_text,
 	_vte_skel_draw_char,
